==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Navrácení k předchozí verzi systému – čekejte, prosím…</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Návrat k předchozí verzi systému se nezdařil.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Aktualizace se nezdařily.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Aktualizace se nezdařily: byly přerušeny.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Aktualizace se nezdařily: chyba DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Aktualizace se nezdařily: nedostatek místa na úložišti.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Opravdu se chcete vrátit k předchozí verzi %1, ze zálohy z %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Zrušit a restartovat</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.31.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>Navrácení k předchozí verzi systému – čekejte, prosím…</translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>Návrat k předchozí verzi systému se nezdařil.</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>Aktualizace se nezdařily.</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>Aktualizace se nezdařily: byly přerušeny.</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>Aktualizace se nezdařily: chyba DPKG.</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>Aktualizace se nezdařily: nedostatek místa na úložišti.</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>Opravdu se chcete vrátit k předchozí verzi %1, ze zálohy z %2?</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>Zrušit a restartovat</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potvrdit</translation>
    </message>
</context>
</TS>
